@@ -35,6 +35,7 @@ unicode_content_tags = set([
     'street',
     'title',
     'u',
+    't',
 ])
 
 # Attribute values should not contain unicode, with some exceptions
@@ -84,6 +85,9 @@ bare_latin_tags = set([
     'title',
     ])
 
+bare_unicode_tags_with_notice = set([
+    't',
+])
 
 def is_svg(e):
     '''
@@ -95,7 +99,6 @@ def is_svg(e):
     else:
         return False
 
-
 for t in bare_unicode_tags:
     assert t in unicode_content_tags
 
