@@ -28,8 +28,11 @@ from xml2rfc import strings, log
 from xml2rfc.uniscripts import is_script
 from xml2rfc.util.date import extract_date, augment_date, format_date, get_expiry_date
 from xml2rfc.util.name import short_author_ascii_name_parts, full_author_name_expansion, short_author_name_parts
-from xml2rfc.util.unicode import ( punctuation, unicode_replacements, unicode_content_tags, bare_unicode_tags,
-    bare_latin_tags, unicode_attributes, downcode, downcode_punctuation, is_svg)
+from xml2rfc.util.unicode import (
+        punctuation, unicode_replacements, unicode_content_tags,
+        bare_unicode_tags, bare_unicode_tags_with_notice,
+        bare_latin_tags, unicode_attributes, downcode, downcode_punctuation,
+        is_svg)
 from xml2rfc.utils import namespaces, find_duplicate_ids, slugify
 
 
@@ -119,6 +122,7 @@ default_options.__dict__ = {
         'v3': True,
         'vocabulary': 'v2',
         'widows': 2,
+        'warn_bare_unicode': False,
     }
 
 class _RfcItem:
@@ -1616,7 +1620,7 @@ deprecated_element_tags = set([
 ])
 
 deprecated_attributes = [
-    # element, attrbute
+    # element, attribute
     ('artwork', 'height'),
     ('artwork', 'width'),
     ('artwork', 'xml:space'),
@@ -2058,6 +2062,8 @@ class BaseV3Writer(object):
                         e.text = downcode(e.text, replacements=replacements)
                 elif e.tag in bare_unicode_tags:
                     pass
+                elif e.tag in bare_unicode_tags_with_notice:
+                    pass
                 elif e.tag in bare_latin_tags and is_script(e.text, 'Latin'):
                     pass
                 elif not e.get('ascii'):
@@ -2216,7 +2222,7 @@ class BaseV3Writer(object):
     def validate_after(self, e, p):
         # XXX: There is an issue with exponential increase in validation time
         # as a function of the number of attributes on the root element, on
-        # the order of minutes for the full set of possble attribute values.
+        # the order of minutes for the full set of possible attribute values.
         # See https://bugzilla.gnome.org/show_bug.cgi?id=133736 .  In our
         # schema, there is no dependency in the underlying schema on the root
         # element attributes.  In order to avoid very long validation times, we
